#' ------------------------------
#' --- This is generated code ---
#' ---      DO NOT EDIT       ---
#' ------------------------------

#' Wrapper for the curl calls to Enterprise Steam
#' @importFrom jsonlite toJSON fromJSON
#' @importFrom methods is
#'
#' @keywords internal
#' @noRd
#'
.steamRPC <- function(conn, method, params) {
    # Validate fields
    if (!is(conn, "SteamConnection")) { stop("conn must be a valid SteamConnection")}

    if (length(params) > 0) {
        params = list(params)
    }
    request <- list(
        method = paste("web", method, sep="."),
        params = params,
        id = conn$uid
    )

    # Args for valid curl
    payload <- toJSON(request, null="list", auto_unbox=TRUE)
    address <- paste(conn$url, "web", sep="")
    userpwd <- paste(conn$username, conn$password, sep=":")
    header <- c(
        'User-Agent' = 'Enterprise Steam R Client',
        'Content-Type' = 'application/json'
    )

    verifyhost <- 2L
    if (conn$verify_ssl == FALSE) {
        verifyhost <- 0L
    }

    opts = curlOptions(userpwd = userpwd, httpauth = 1L, ssl.verifypeer = conn$verify_ssl, ssl.verifyhost = verifyhost)

    if (conn$cacert != "") {
        opts = curlOptions(cainfo = conn$cacert, .opts = opts)
    }

    # Error handling values
    h <- basicHeaderGatherer()
    .__curlErr = FALSE
    .__curlErrMessage <- ""
    httpStatusCode = -1L
    httpStatusMessage = ""

    # Return values
    g <- basicTextGatherer(.mapUnicode = FALSE)

    tmp <- tryCatch(curlPerform(
            url = address,
            postfields = payload,
            writefunction = g$update,
            headerfunction = h$update,
            httpheader = header,
            curl = conn$curl,
            .opts = opts
        ),
        error = function(x) { .__curlErr <<- TRUE; .__curlErrMessage <<- x$message }
    )
    if (.__curlErr) {
        stop(sprintf("%s: %s", .__curlErrMessage, g$value()[1]))
    } else if (h$value()["status"] != 200 && h$value()["status"] != 307){
        stop(g$value()[1])
    }
    response <- fromJSON(g$value())
    if (!is.null(response$error)) {
        stop(response$error)
    }

    if (exists("conn", 1)) {
        conn$uid <<- conn$uid + 1
    }
    response$result
}


#' Ping the Enterprise Steam server
#'
#' @param conn Valid SteamConnection handle.
#' @param input \code{character} Message to send
#'
#' @keywords internal
#' @noRd
#'
.pingServer <- function(conn, input) {
    request <- list(
        input = input
    )

    .steamRPC(conn, "PingServer", request)
}

#' Get Enterprise Steam start up configurations
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetConfig", request)
}

#' Set authentication config
#'
#' @param conn Valid SteamConnection handle.
#' @param enabled_type \code{character} No description available
#' @param ldap No description available
#' @param saml No description available
#' @param pam No description available
#' @param oidc No description available
#'
#' @keywords internal
#' @noRd
#'
.setAuthentication <- function(conn, enabled_type, ldap, saml, pam, oidc) {
    request <- list(
        enabled_type = enabled_type,
        ldap = ldap,
        saml = saml,
        pam = pam,
        oidc = oidc
    )

    .steamRPC(conn, "SetAuthentication", request)
}

#' Get authentication config
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getAuthentication <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetAuthentication", request)
}

#' Test LDAP security configurations
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.testLdapConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "TestLdapConfig", request)
}

#' Get roles config
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getRolesConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetRolesConfig", request)
}

#' Set roles config
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setRolesConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetRolesConfig", request)
}

#' Set configuration for YARN deployment backend
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setHadoopConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetHadoopConfig", request)
}

#' Get configuration for YARN deployment backend
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getHadoopConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetHadoopConfig", request)
}

#' Test generation of Hive token
#'
#' @param conn Valid SteamConnection handle.
#' @param username \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.testGenerateHiveToken <- function(conn, username) {
    request <- list(
        username = username
    )

    .steamRPC(conn, "TestGenerateHiveToken", request)
}

#' Set configuration for Kubernetes deployment backend
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setKubernetesConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetKubernetesConfig", request)
}

#' Get configuration for Kubernetes deployment backend
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getKubernetesConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetKubernetesConfig", request)
}

#' Set configuration for HDFS on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setKubernetesHdfsConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetKubernetesHdfsConfig", request)
}

#' Get configuration for HDFS on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getKubernetesHdfsConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetKubernetesHdfsConfig", request)
}

#' Create a global startup parameter for launching H2O clusters
#'
#' @param conn Valid SteamConnection handle.
#' @param parameter No description available
#'
#' @keywords internal
#' @noRd
#'
.createH2oStartupParameter <- function(conn, parameter) {
    request <- list(
        parameter = parameter
    )

    .steamRPC(conn, "CreateH2oStartupParameter", request)
}

#' Get a global startup parameter for launching H2O clusters
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getH2oStartupParameters <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetH2oStartupParameters", request)
}

#' Update a global startup parameter for launching H2O clusters
#'
#' @param conn Valid SteamConnection handle.
#' @param id \code{numeric} No description available
#' @param parameter No description available
#'
#' @keywords internal
#' @noRd
#'
.updateH2oStartupParameter <- function(conn, id, parameter) {
    request <- list(
        id = id,
        parameter = parameter
    )

    .steamRPC(conn, "UpdateH2oStartupParameter", request)
}

#' Delete a global startup parameter for launching H2O clusters
#'
#' @param conn Valid SteamConnection handle.
#' @param id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.removeH2oStartupParameter <- function(conn, id) {
    request <- list(
        id = id
    )

    .steamRPC(conn, "RemoveH2oStartupParameter", request)
}

#' Launch H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.launchH2oCluster <- function(conn, parameters) {
    request <- list(
        parameters = parameters
    )

    .steamRPC(conn, "LaunchH2oCluster", request)
}

#' Start stopped H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param id \code{numeric} No description available
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.startH2oCluster <- function(conn, id, parameters) {
    request <- list(
        id = id,
        parameters = parameters
    )

    .steamRPC(conn, "StartH2oCluster", request)
}

#' Get all my H2O clusters
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getH2oClusters <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetH2oClusters", request)
}

#' Get H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oCluster <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "GetH2oCluster", request)
}

#' Get H2O cluster by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oClusterByName <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetH2oClusterByName", request)
}

#' Stop H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#' @param should_save \code{logical} No description available
#'
#' @keywords internal
#' @noRd
#'
.stopH2oCluster <- function(conn, cluster_id, should_save) {
    request <- list(
        cluster_id = cluster_id,
        should_save = should_save
    )

    .steamRPC(conn, "StopH2oCluster", request)
}

#' Mark H2O cluster as failed
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.failH2oCluster <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "FailH2oCluster", request)
}

#' Delete H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteH2oCluster <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "DeleteH2oCluster", request)
}

#' Get H2O cluster logs
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oClusterLogs <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "GetH2oClusterLogs", request)
}

#' Get H2O configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getH2oConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetH2oConfig", request)
}

#' Set H2O configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setH2oConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetH2oConfig", request)
}

#' Import engine from server path
#'
#' @param conn Valid SteamConnection handle.
#' @param path \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.importH2oEngine <- function(conn, path) {
    request <- list(
        path = path
    )

    .steamRPC(conn, "ImportH2oEngine", request)
}

#' Get H2O engine details
#'
#' @param conn Valid SteamConnection handle.
#' @param engine_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oEngine <- function(conn, engine_id) {
    request <- list(
        engine_id = engine_id
    )

    .steamRPC(conn, "GetH2oEngine", request)
}

#' Get an H2O engine by a version substring
#'
#' @param conn Valid SteamConnection handle.
#' @param version \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oEngineByVersion <- function(conn, version) {
    request <- list(
        version = version
    )

    .steamRPC(conn, "GetH2oEngineByVersion", request)
}

#' List H2O engines
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getH2oEngines <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetH2oEngines", request)
}

#' Delete an H2O engine
#'
#' @param conn Valid SteamConnection handle.
#' @param engine_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteH2oEngine <- function(conn, engine_id) {
    request <- list(
        engine_id = engine_id
    )

    .steamRPC(conn, "DeleteH2oEngine", request)
}

#' List all entity types
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getAllEntityTypes <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetAllEntityTypes", request)
}

#' List all permissions
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getAllPermissions <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetAllPermissions", request)
}

#' List permissions for a role
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getPermissionsForRole <- function(conn, role_id) {
    request <- list(
        role_id = role_id
    )

    .steamRPC(conn, "GetPermissionsForRole", request)
}

#' List permissions for an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getPermissionsForIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "GetPermissionsForIdentity", request)
}

#' Get estimated cluster memory
#'
#' @param conn Valid SteamConnection handle.
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.getEstimatedClusterMemory <- function(conn, parameters) {
    request <- list(
        parameters = parameters
    )

    .steamRPC(conn, "GetEstimatedClusterMemory", request)
}

#' Create a role
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} A string name.
#' @param description \code{character} A string description
#'
#' @keywords internal
#' @noRd
#'
.createRole <- function(conn, name, description) {
    request <- list(
        name = name,
        description = description
    )

    .steamRPC(conn, "CreateRole", request)
}

#' List roles
#'
#' @param conn Valid SteamConnection handle.
#' @param offset \code{numeric} An offset uint start the search on.
#' @param limit \code{numeric} The maximum uint objects.
#'
#' @keywords internal
#' @noRd
#'
.getRoles <- function(conn, offset, limit) {
    request <- list(
        offset = offset,
        limit = limit
    )

    .steamRPC(conn, "GetRoles", request)
}

#' List roles for an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getRolesForIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "GetRolesForIdentity", request)
}

#' Get role details
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getRole <- function(conn, role_id) {
    request <- list(
        role_id = role_id
    )

    .steamRPC(conn, "GetRole", request)
}

#' Get role details by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} A role name.
#'
#' @keywords internal
#' @noRd
#'
.getRoleByName <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetRoleByName", request)
}

#' Update a role
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#' @param name \code{character} A string name.
#' @param description \code{character} A string description
#'
#' @keywords internal
#' @noRd
#'
.updateRole <- function(conn, role_id, name, description) {
    request <- list(
        role_id = role_id,
        name = name,
        description = description
    )

    .steamRPC(conn, "UpdateRole", request)
}

#' Delete a role
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.deleteRole <- function(conn, role_id) {
    request <- list(
        role_id = role_id
    )

    .steamRPC(conn, "DeleteRole", request)
}

#' Link a role with permissions
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#' @param permission_ids \code{numeric} A list of Integer IDs for permissions in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.linkRoleWithPermissions <- function(conn, role_id, permission_ids) {
    request <- list(
        role_id = role_id,
        permission_ids = permission_ids
    )

    .steamRPC(conn, "LinkRoleWithPermissions", request)
}

#' Link a role with a permission
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#' @param permission_id \code{numeric} Integer ID of a permission in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.linkRoleWithPermission <- function(conn, role_id, permission_id) {
    request <- list(
        role_id = role_id,
        permission_id = permission_id
    )

    .steamRPC(conn, "LinkRoleWithPermission", request)
}

#' Unlink a role from a permission
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#' @param permission_id \code{numeric} Integer ID of a permission in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.unlinkRoleFromPermission <- function(conn, role_id, permission_id) {
    request <- list(
        role_id = role_id,
        permission_id = permission_id
    )

    .steamRPC(conn, "UnlinkRoleFromPermission", request)
}

#' Create a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} A string name.
#' @param description \code{character} A string description
#'
#' @keywords internal
#' @noRd
#'
.createWorkgroup <- function(conn, name, description) {
    request <- list(
        name = name,
        description = description
    )

    .steamRPC(conn, "CreateWorkgroup", request)
}

#' List workgroups
#'
#' @param conn Valid SteamConnection handle.
#' @param offset \code{numeric} An offset uint start the search on.
#' @param limit \code{numeric} The maximum uint objects.
#'
#' @keywords internal
#' @noRd
#'
.getWorkgroups <- function(conn, offset, limit) {
    request <- list(
        offset = offset,
        limit = limit
    )

    .steamRPC(conn, "GetWorkgroups", request)
}

#' List workgroups for an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getWorkgroupsForIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "GetWorkgroupsForIdentity", request)
}

#' Get workgroup details
#'
#' @param conn Valid SteamConnection handle.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getWorkgroup <- function(conn, workgroup_id) {
    request <- list(
        workgroup_id = workgroup_id
    )

    .steamRPC(conn, "GetWorkgroup", request)
}

#' Get workgroup details by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} A string name.
#'
#' @keywords internal
#' @noRd
#'
.getWorkgroupByName <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetWorkgroupByName", request)
}

#' Update a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param workgroup_id \code{numeric} Integer ID of a workgrou in Enterprise Steam.
#' @param name \code{character} A string name.
#' @param description \code{character} A string description
#'
#' @keywords internal
#' @noRd
#'
.updateWorkgroup <- function(conn, workgroup_id, name, description) {
    request <- list(
        workgroup_id = workgroup_id,
        name = name,
        description = description
    )

    .steamRPC(conn, "UpdateWorkgroup", request)
}

#' Delete a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.deleteWorkgroup <- function(conn, workgroup_id) {
    request <- list(
        workgroup_id = workgroup_id
    )

    .steamRPC(conn, "DeleteWorkgroup", request)
}

#' Create an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} A string name.
#' @param password \code{character} A string password
#' @param yarn_queue \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.createIdentity <- function(conn, name, password, yarn_queue) {
    request <- list(
        name = name,
        password = password,
        yarn_queue = yarn_queue
    )

    .steamRPC(conn, "CreateIdentity", request)
}

#' List identities
#'
#' @param conn Valid SteamConnection handle.
#' @param offset \code{numeric} An offset uint start the search on.
#' @param limit \code{numeric} The maximum uint objects.
#'
#' @keywords internal
#' @noRd
#'
.getIdentities <- function(conn, offset, limit) {
    request <- list(
        offset = offset,
        limit = limit
    )

    .steamRPC(conn, "GetIdentities", request)
}

#' List identities for a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getIdentitiesForWorkgroup <- function(conn, workgroup_id) {
    request <- list(
        workgroup_id = workgroup_id
    )

    .steamRPC(conn, "GetIdentitiesForWorkgroup", request)
}

#' List identities for a role
#'
#' @param conn Valid SteamConnection handle.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getIdentitiesForRole <- function(conn, role_id) {
    request <- list(
        role_id = role_id
    )

    .steamRPC(conn, "GetIdentitiesForRole", request)
}

#' Get a list of identities and roles with access to an entity
#'
#' @param conn Valid SteamConnection handle.
#' @param entity_type \code{numeric} An entity type ID.
#' @param entity_id \code{numeric} An entity ID.
#'
#' @keywords internal
#' @noRd
#'
.getIdentitiesForEntity <- function(conn, entity_type, entity_id) {
    request <- list(
        entity_type = entity_type,
        entity_id = entity_id
    )

    .steamRPC(conn, "GetIdentitiesForEntity", request)
}

#' Get identity details
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "GetIdentity", request)
}

#' Get identity details by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} An identity name.
#'
#' @keywords internal
#' @noRd
#'
.getIdentityByName <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetIdentityByName", request)
}

#' Update an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#' @param password \code{character} Password for identity
#'
#' @keywords internal
#' @noRd
#'
.updateIdentity <- function(conn, identity_id, password) {
    request <- list(
        identity_id = identity_id,
        password = password
    )

    .steamRPC(conn, "UpdateIdentity", request)
}

#' Update an identity login type
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#' @param auth_type \code{character} The auth type to use for login
#'
#' @keywords internal
#' @noRd
#'
.updateIdentityAuth <- function(conn, identity_id, auth_type) {
    request <- list(
        identity_id = identity_id,
        auth_type = auth_type
    )

    .steamRPC(conn, "UpdateIdentityAuth", request)
}

#' Update yarn queues of the idenity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#' @param yarn_queue \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.updateIdentityYarn <- function(conn, identity_id, yarn_queue) {
    request <- list(
        identity_id = identity_id,
        yarn_queue = yarn_queue
    )

    .steamRPC(conn, "UpdateIdentityYarn", request)
}

#' Update UID and GID of identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#' @param uid \code{numeric} No description available
#' @param gid \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.updateIdentityUidGid <- function(conn, identity_id, uid, gid) {
    request <- list(
        identity_id = identity_id,
        uid = uid,
        gid = gid
    )

    .steamRPC(conn, "UpdateIdentityUidGid", request)
}

#' Activate an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.activateIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "ActivateIdentity", request)
}

#' Deactivate an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.deactivateIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "DeactivateIdentity", request)
}

#' Link an identity with a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.linkIdentityWithWorkgroup <- function(conn, identity_id, workgroup_id) {
    request <- list(
        identity_id = identity_id,
        workgroup_id = workgroup_id
    )

    .steamRPC(conn, "LinkIdentityWithWorkgroup", request)
}

#' Unlink an identity from a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.unlinkIdentityFromWorkgroup <- function(conn, identity_id, workgroup_id) {
    request <- list(
        identity_id = identity_id,
        workgroup_id = workgroup_id
    )

    .steamRPC(conn, "UnlinkIdentityFromWorkgroup", request)
}

#' Link an identity with a role
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.linkIdentityWithRole <- function(conn, identity_id, role_id) {
    request <- list(
        identity_id = identity_id,
        role_id = role_id
    )

    .steamRPC(conn, "LinkIdentityWithRole", request)
}

#' Unlink an identity from a role
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} Integer ID of an identity in Enterprise Steam.
#' @param role_id \code{numeric} Integer ID of a role in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.unlinkIdentityFromRole <- function(conn, identity_id, role_id) {
    request <- list(
        identity_id = identity_id,
        role_id = role_id
    )

    .steamRPC(conn, "UnlinkIdentityFromRole", request)
}

#' Share an entity with a workgroup
#'
#' @param conn Valid SteamConnection handle.
#' @param kind \code{character} Type of permission. Can be view, edit, or own.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#' @param entity_type_id \code{numeric} Integer ID for the type of entity.
#' @param entity_id \code{numeric} Integer ID for an entity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.shareEntity <- function(conn, kind, workgroup_id, entity_type_id, entity_id) {
    request <- list(
        kind = kind,
        workgroup_id = workgroup_id,
        entity_type_id = entity_type_id,
        entity_id = entity_id
    )

    .steamRPC(conn, "ShareEntity", request)
}

#' List privileges for an entity
#'
#' @param conn Valid SteamConnection handle.
#' @param entity_type_id \code{numeric} Integer ID for the type of entity.
#' @param entity_id \code{numeric} Integer ID for an entity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.getPrivileges <- function(conn, entity_type_id, entity_id) {
    request <- list(
        entity_type_id = entity_type_id,
        entity_id = entity_id
    )

    .steamRPC(conn, "GetPrivileges", request)
}

#' Unshare an entity
#'
#' @param conn Valid SteamConnection handle.
#' @param kind \code{character} Type of permission. Can be view, edit, or own.
#' @param workgroup_id \code{numeric} Integer ID of a workgroup in Enterprise Steam.
#' @param entity_type_id \code{numeric} Integer ID for the type of entity.
#' @param entity_id \code{numeric} Integer ID for an entity in Enterprise Steam.
#'
#' @keywords internal
#' @noRd
#'
.unshareEntity <- function(conn, kind, workgroup_id, entity_type_id, entity_id) {
    request <- list(
        kind = kind,
        workgroup_id = workgroup_id,
        entity_type_id = entity_type_id,
        entity_id = entity_id
    )

    .steamRPC(conn, "UnshareEntity", request)
}

#' List audit trail records for an entity
#'
#' @param conn Valid SteamConnection handle.
#' @param entity_type_id \code{numeric} Integer ID for the type of entity.
#' @param entity_id \code{numeric} Integer ID for an entity in Enterprise Steam.
#' @param offset \code{numeric} An offset uint start the search on.
#' @param limit \code{numeric} The maximum uint objects.
#'
#' @keywords internal
#' @noRd
#'
.getHistory <- function(conn, entity_type_id, entity_id, offset, limit) {
    request <- list(
        entity_type_id = entity_type_id,
        entity_id = entity_id,
        offset = offset,
        limit = limit
    )

    .steamRPC(conn, "GetHistory", request)
}

#' Set license from license text
#'
#' @param conn Valid SteamConnection handle.
#' @param license \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.setLicense <- function(conn, license) {
    request <- list(
        license = license
    )

    .steamRPC(conn, "SetLicense", request)
}

#' Get the current provided license
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getLicense <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetLicense", request)
}

#' Delete the current license
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.deleteLicense <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "DeleteLicense", request)
}

#' Invalidate LDAP cache
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.invalidateLdapCache <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "InvalidateLdapCache", request)
}

#' Change my password
#'
#' @param conn Valid SteamConnection handle.
#' @param password \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.changeMyPassword <- function(conn, password) {
    request <- list(
        password = password
    )

    .steamRPC(conn, "ChangeMyPassword", request)
}

#' Reset user's password and get a new one'
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.resetPasswordForIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "ResetPasswordForIdentity", request)
}

#' Generate new login token for identity
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.generateIdentityToken <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GenerateIdentityToken", request)
}

#' Set identity as admin overriding roles
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#' @param is_admin \code{logical} No description available
#'
#' @keywords internal
#' @noRd
#'
.setIdentityAdminOverride <- function(conn, identity_id, is_admin) {
    request <- list(
        identity_id = identity_id,
        is_admin = is_admin
    )

    .steamRPC(conn, "SetIdentityAdminOverride", request)
}

#' Terminates all clusters and instances owned by the user
#'
#' @param conn Valid SteamConnection handle.
#' @param username \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.terminateIdentityResources <- function(conn, username) {
    request <- list(
        username = username
    )

    .steamRPC(conn, "TerminateIdentityResources", request)
}

#' Get Sparkling Water clusters
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getSparklingClusters <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetSparklingClusters", request)
}

#' Get Sparkling Water cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getSparklingCluster <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "GetSparklingCluster", request)
}

#' Get Sparkling Water cluster by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getSparklingClusterByName <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetSparklingClusterByName", request)
}

#' Get Sparkling cluster logs
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getSparklingClusterLogs <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "GetSparklingClusterLogs", request)
}

#' Launch Sparkling Water cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.launchSparklingCluster <- function(conn, parameters) {
    request <- list(
        parameters = parameters
    )

    .steamRPC(conn, "LaunchSparklingCluster", request)
}

#' Start stopped Sparkling Water cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param id \code{numeric} No description available
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.startSparklingCluster <- function(conn, id, parameters) {
    request <- list(
        id = id,
        parameters = parameters
    )

    .steamRPC(conn, "StartSparklingCluster", request)
}

#' Stop Sparkling Water cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#' @param should_save \code{logical} No description available
#'
#' @keywords internal
#' @noRd
#'
.stopSparklingCluster <- function(conn, cluster_id, should_save) {
    request <- list(
        cluster_id = cluster_id,
        should_save = should_save
    )

    .steamRPC(conn, "StopSparklingCluster", request)
}

#' Mark cluster as failed
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.failSparklingCluster <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "FailSparklingCluster", request)
}

#' Delete Sparkling Water cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteSparklingCluster <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "DeleteSparklingCluster", request)
}

#' Send statement to Sparkling Water cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#' @param statement \code{character} No description available
#' @param statement_kind \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.sendSparklingStatement <- function(conn, cluster_id, statement, statement_kind) {
    request <- list(
        cluster_id = cluster_id,
        statement = statement,
        statement_kind = statement_kind
    )

    .steamRPC(conn, "SendSparklingStatement", request)
}

#' Get Sparkling Water configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getSparklingConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetSparklingConfig", request)
}

#' Set Sparkling Water configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setSparklingConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetSparklingConfig", request)
}

#' List sparkling engines
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getSparklingEngines <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetSparklingEngines", request)
}

#' Import sparkling engine from server path
#'
#' @param conn Valid SteamConnection handle.
#' @param path \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.importSparklingEngine <- function(conn, path) {
    request <- list(
        path = path
    )

    .steamRPC(conn, "ImportSparklingEngine", request)
}

#' Get sparkling engine details
#'
#' @param conn Valid SteamConnection handle.
#' @param engine_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getSparklingEngine <- function(conn, engine_id) {
    request <- list(
        engine_id = engine_id
    )

    .steamRPC(conn, "GetSparklingEngine", request)
}

#' Get a sparkling engine by a version substring
#'
#' @param conn Valid SteamConnection handle.
#' @param version \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getSparklingEngineByVersion <- function(conn, version) {
    request <- list(
        version = version
    )

    .steamRPC(conn, "GetSparklingEngineByVersion", request)
}

#' Delete a sparkling engine
#'
#' @param conn Valid SteamConnection handle.
#' @param engine_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteSparklingEngine <- function(conn, engine_id) {
    request <- list(
        engine_id = engine_id
    )

    .steamRPC(conn, "DeleteSparklingEngine", request)
}

#' Get python environment details
#'
#' @param conn Valid SteamConnection handle.
#' @param environment_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getPythonEnvironment <- function(conn, environment_id) {
    request <- list(
        environment_id = environment_id
    )

    .steamRPC(conn, "GetPythonEnvironment", request)
}

#' Get python environment details by environment name
#'
#' @param conn Valid SteamConnection handle.
#' @param environment_name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getPythonEnvironmentByName <- function(conn, environment_name) {
    request <- list(
        environment_name = environment_name
    )

    .steamRPC(conn, "GetPythonEnvironmentByName", request)
}

#' Get python environments available to current user
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getPythonEnvironments <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetPythonEnvironments", request)
}

#' Create new python environment
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#' @param conda_pack_archive_name \code{character} No description available
#' @param pyspark_python_path \code{character} No description available
#' @param profile_ids \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.createPythonEnvironment <- function(conn, name, conda_pack_archive_name, pyspark_python_path, profile_ids) {
    request <- list(
        name = name,
        conda_pack_archive_name = conda_pack_archive_name,
        pyspark_python_path = pyspark_python_path,
        profile_ids = profile_ids
    )

    .steamRPC(conn, "CreatePythonEnvironment", request)
}

#' Delete python environment
#'
#' @param conn Valid SteamConnection handle.
#' @param environment_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deletePythonEnvironment <- function(conn, environment_id) {
    request <- list(
        environment_id = environment_id
    )

    .steamRPC(conn, "DeletePythonEnvironment", request)
}

#' Create new profile
#'
#' @param conn Valid SteamConnection handle.
#' @param profile No description available
#'
#' @keywords internal
#' @noRd
#'
.createProfile <- function(conn, profile) {
    request <- list(
        profile = profile
    )

    .steamRPC(conn, "CreateProfile", request)
}

#' Get existing profile by ID
#'
#' @param conn Valid SteamConnection handle.
#' @param profile_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getProfile <- function(conn, profile_id) {
    request <- list(
        profile_id = profile_id
    )

    .steamRPC(conn, "GetProfile", request)
}

#' Get existing profile by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getProfileByName <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetProfileByName", request)
}

#' Get existing profiles by ID
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getProfiles <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetProfiles", request)
}

#' Get profiles for an identity
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getProfilesForIdentity <- function(conn, identity_id) {
    request <- list(
        identity_id = identity_id
    )

    .steamRPC(conn, "GetProfilesForIdentity", request)
}

#' Update existing profile by ID
#'
#' @param conn Valid SteamConnection handle.
#' @param profile No description available
#'
#' @keywords internal
#' @noRd
#'
.updateProfile <- function(conn, profile) {
    request <- list(
        profile = profile
    )

    .steamRPC(conn, "UpdateProfile", request)
}

#' Delete existing profile by ID
#'
#' @param conn Valid SteamConnection handle.
#' @param profile_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteProfile <- function(conn, profile_id) {
    request <- list(
        profile_id = profile_id
    )

    .steamRPC(conn, "DeleteProfile", request)
}

#' Link an identity with a profile
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#' @param profile_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.linkIdentityWithProfile <- function(conn, identity_id, profile_id) {
    request <- list(
        identity_id = identity_id,
        profile_id = profile_id
    )

    .steamRPC(conn, "LinkIdentityWithProfile", request)
}

#' Unlink an identity from a profile
#'
#' @param conn Valid SteamConnection handle.
#' @param identity_id \code{numeric} No description available
#' @param profile_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.unlinkIdentityFromProfile <- function(conn, identity_id, profile_id) {
    request <- list(
        identity_id = identity_id,
        profile_id = profile_id
    )

    .steamRPC(conn, "UnlinkIdentityFromProfile", request)
}

#' Get profile usage statistics
#'
#' @param conn Valid SteamConnection handle.
#' @param profile_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getProfileUsage <- function(conn, profile_id) {
    request <- list(
        profile_id = profile_id
    )

    .steamRPC(conn, "GetProfileUsage", request)
}

#' Get my Driverless AI instances
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessInstances <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDriverlessInstances", request)
}

#' Get Driverless AI instance by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessInstance <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetDriverlessInstance", request)
}

#' Get Driverless AI instance by ID
#'
#' @param conn Valid SteamConnection handle.
#' @param id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessInstanceByID <- function(conn, id) {
    request <- list(
        id = id
    )

    .steamRPC(conn, "GetDriverlessInstanceByID", request)
}

#' Launch Driverless AI instance
#'
#' @param conn Valid SteamConnection handle.
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.launchDriverlessInstance <- function(conn, parameters) {
    request <- list(
        parameters = parameters
    )

    .steamRPC(conn, "LaunchDriverlessInstance", request)
}

#' Start Driverless AI instance
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.startDriverlessInstance <- function(conn, instance_id, parameters) {
    request <- list(
        instance_id = instance_id,
        parameters = parameters
    )

    .steamRPC(conn, "StartDriverlessInstance", request)
}

#' Stop Driverless AI instance
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.stopDriverlessInstance <- function(conn, instance_id) {
    request <- list(
        instance_id = instance_id
    )

    .steamRPC(conn, "StopDriverlessInstance", request)
}

#' Terminate Driverless AI instance
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.terminateDriverlessInstance <- function(conn, instance_id) {
    request <- list(
        instance_id = instance_id
    )

    .steamRPC(conn, "TerminateDriverlessInstance", request)
}

#' Mark Driverless AI instance as failed
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.failDriverlessInstance <- function(conn, instance_id) {
    request <- list(
        instance_id = instance_id
    )

    .steamRPC(conn, "FailDriverlessInstance", request)
}

#' Upgrade Driverless AI instance
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#' @param version \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.upgradeDriverlessInstance <- function(conn, instance_id, version) {
    request <- list(
        instance_id = instance_id,
        version = version
    )

    .steamRPC(conn, "UpgradeDriverlessInstance", request)
}

#' Get Driverless AI instance logs
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessInstanceLogs <- function(conn, instance_id) {
    request <- list(
        instance_id = instance_id
    )

    .steamRPC(conn, "GetDriverlessInstanceLogs", request)
}

#' Get Driverless AI engines
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessEngines <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDriverlessEngines", request)
}

#' Set Driverless AI config
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setDriverlessConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetDriverlessConfig", request)
}

#' Get Driverless AI config
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDriverlessConfig", request)
}

#' Get Driverless AI Python client info
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessClient <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDriverlessClient", request)
}

#' Get engines for Driverless AI on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessKubernetesEngines <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDriverlessKubernetesEngines", request)
}

#' Add engine for Driverless AI on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#' @param engine No description available
#'
#' @keywords internal
#' @noRd
#'
.addDriverlessKubernetesEngine <- function(conn, engine) {
    request <- list(
        engine = engine
    )

    .steamRPC(conn, "AddDriverlessKubernetesEngine", request)
}

#' Remove engine for Driverless AI on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#' @param version \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.removeDriverlessKubernetesEngine <- function(conn, version) {
    request <- list(
        version = version
    )

    .steamRPC(conn, "RemoveDriverlessKubernetesEngine", request)
}

#' Launch Driverless AI multinode cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.launchDriverlessMultinode <- function(conn, parameters) {
    request <- list(
        parameters = parameters
    )

    .steamRPC(conn, "LaunchDriverlessMultinode", request)
}

#' Get Driverless AI multinode cluster by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessMultinode <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetDriverlessMultinode", request)
}

#' Get all Driverless AI multinode clusters
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDriverlessMultinodes <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDriverlessMultinodes", request)
}

#' Terminate Driverless AI multinode cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.terminateDriverlessMultinode <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "TerminateDriverlessMultinode", request)
}

#' Restart failed Driverless AI multinode cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.restartDriverlessMultinode <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "RestartDriverlessMultinode", request)
}

#' Set security configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setSecurityConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetSecurityConfig", request)
}

#' Set security configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getSecurityConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetSecurityConfig", request)
}

#' Set logging configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setLoggingConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetLoggingConfig", request)
}

#' Get logging configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getLoggingConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetLoggingConfig", request)
}

#' Get config metadata
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getConfigMeta <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetConfigMeta", request)
}

#' Get Licensing configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setLicensingConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetLicensingConfig", request)
}

#' Get Licensing configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getLicensingConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetLicensingConfig", request)
}

#' Get events associated with given entity
#'
#' @param conn Valid SteamConnection handle.
#' @param entity_type \code{character} No description available
#' @param entity_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getEvents <- function(conn, entity_type, entity_id) {
    request <- list(
        entity_type = entity_type,
        entity_id = entity_id
    )

    .steamRPC(conn, "GetEvents", request)
}

#' Get all documentation
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getDocumentation <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetDocumentation", request)
}

#' Delete a single documentation piece
#'
#' @param conn Valid SteamConnection handle.
#' @param item_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteDocumentation <- function(conn, item_id) {
    request <- list(
        item_id = item_id
    )

    .steamRPC(conn, "DeleteDocumentation", request)
}

#' Create Kubernetes volume
#'
#' @param conn Valid SteamConnection handle.
#' @param volume No description available
#'
#' @keywords internal
#' @noRd
#'
.createKubernetesVolume <- function(conn, volume) {
    request <- list(
        volume = volume
    )

    .steamRPC(conn, "CreateKubernetesVolume", request)
}

#' Get all created Kubernetes volumes
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getKubernetesVolumes <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetKubernetesVolumes", request)
}

#' Delete Kubernetes volume
#'
#' @param conn Valid SteamConnection handle.
#' @param id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteKubernetesVolume <- function(conn, id) {
    request <- list(
        id = id
    )

    .steamRPC(conn, "DeleteKubernetesVolume", request)
}

#' Set global Minio configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setMinioConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetMinioConfig", request)
}

#' Get global Minio configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getMinioConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetMinioConfig", request)
}

#' Set personal Minio credentials
#'
#' @param conn Valid SteamConnection handle.
#' @param credentials No description available
#'
#' @keywords internal
#' @noRd
#'
.setPersonalMinioCredentials <- function(conn, credentials) {
    request <- list(
        credentials = credentials
    )

    .steamRPC(conn, "SetPersonalMinioCredentials", request)
}

#' Get personal Minio credentials
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getPersonalMinioCredentials <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetPersonalMinioCredentials", request)
}

#' Set global H2O.ai Storage configuration
#'
#' @param conn Valid SteamConnection handle.
#' @param config No description available
#'
#' @keywords internal
#' @noRd
#'
.setStorageConfig <- function(conn, config) {
    request <- list(
        config = config
    )

    .steamRPC(conn, "SetStorageConfig", request)
}

#' Get global H2O.ai Storage configuration
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getStorageConfig <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetStorageConfig", request)
}

#' Get details to establish personal Open ID token provider
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getOidcTokenProvider <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetOidcTokenProvider", request)
}

#' Get my H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getH2oKubernetesClusters <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetH2oKubernetesClusters", request)
}

#' Get H2O cluster by id
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oKubernetesClusterById <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "GetH2oKubernetesClusterById", request)
}

#' Stop H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.stopH2oKubernetesClusterById <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "StopH2oKubernetesClusterById", request)
}

#' Mark H2O cluster as failed
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.failH2oKubernetesClusterById <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "FailH2oKubernetesClusterById", request)
}

#' Terminate H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteH2oKubernetesClusterById <- function(conn, cluster_id) {
    request <- list(
        cluster_id = cluster_id
    )

    .steamRPC(conn, "DeleteH2oKubernetesClusterById", request)
}

#' Get H2O cluster by name
#'
#' @param conn Valid SteamConnection handle.
#' @param cluster_name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oKubernetesClusterByName <- function(conn, cluster_name) {
    request <- list(
        cluster_name = cluster_name
    )

    .steamRPC(conn, "GetH2oKubernetesClusterByName", request)
}

#' Launch H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param parameters No description available
#'
#' @keywords internal
#' @noRd
#'
.launchH2oKubernetesCluster <- function(conn, parameters) {
    request <- list(
        parameters = parameters
    )

    .steamRPC(conn, "LaunchH2oKubernetesCluster", request)
}

#' Get H2O cluster logs
#'
#' @param conn Valid SteamConnection handle.
#' @param instance_id \code{numeric} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oKubernetesClusterLogs <- function(conn, instance_id) {
    request <- list(
        instance_id = instance_id
    )

    .steamRPC(conn, "GetH2oKubernetesClusterLogs", request)
}

#' Get engines for H2O on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#'
#' @keywords internal
#' @noRd
#'
.getH2oKubernetesEngines <- function(conn) {
    request <- list(
    )

    .steamRPC(conn, "GetH2oKubernetesEngines", request)
}

#' Add engine for H2O on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#' @param engine No description available
#'
#' @keywords internal
#' @noRd
#'
.addH2oKubernetesEngine <- function(conn, engine) {
    request <- list(
        engine = engine
    )

    .steamRPC(conn, "AddH2oKubernetesEngine", request)
}

#' Remove engine for H2O on Kubernetes
#'
#' @param conn Valid SteamConnection handle.
#' @param version \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.removeH2oKubernetesEngine <- function(conn, version) {
    request <- list(
        version = version
    )

    .steamRPC(conn, "RemoveH2oKubernetesEngine", request)
}

#' Get H2O cluster by name
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.getH2oKubernetesCluster <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "GetH2oKubernetesCluster", request)
}

#' Stop H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.stopH2oKubernetesCluster <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "StopH2oKubernetesCluster", request)
}

#' Mark H2O cluster as failed
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.failH2oKubernetesCluster <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "FailH2oKubernetesCluster", request)
}

#' Terminate H2O cluster
#'
#' @param conn Valid SteamConnection handle.
#' @param name \code{character} No description available
#'
#' @keywords internal
#' @noRd
#'
.deleteH2oKubernetesCluster <- function(conn, name) {
    request <- list(
        name = name
    )

    .steamRPC(conn, "DeleteH2oKubernetesCluster", request)
}

#' Does nothing
#'
#' @param conn Valid SteamConnection handle.
#' @param a No description available
#' @param b No description available
#' @param c No description available
#' @param d No description available
#' @param f No description available
#' @param g No description available
#' @param h No description available
#' @param i No description available
#' @param j No description available
#' @param k No description available
#' @param l No description available
#' @param m No description available
#' @param n No description available
#'
#' @keywords internal
#' @noRd
#'
.dummy <- function(conn, a, b, c, d, f, g, h, i, j, k, l, m, n) {
    request <- list(
        a = a,
        b = b,
        c = c,
        d = d,
        f = f,
        g = g,
        h = h,
        i = i,
        j = j,
        k = k,
        l = l,
        m = m,
        n = n
    )

    .steamRPC(conn, "Dummy", request)
}

